% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_ps2DSignal.R
\name{plot.ps2dsignal}
\alias{plot.ps2dsignal}
\title{Plotting function for \code{ps2DSignal}}
\usage{
\method{plot}{ps2dsignal}(x, ..., xlab = " ", ylab = " ", Resol = 200)
}
\arguments{
\item{x}{the P-spline object, usually from \code{ps2DSignal}.}

\item{...}{other parameters.}

\item{xlab}{label for the x-axis, e.g. "my x" (quotes required).}

\item{ylab}{label for the y-axis, e.g. "my y" (quotes required).}

\item{Resol}{Resolution of bgrid (default \code{Resol = 200}).}
}
\value{
\item{Plot}{a plot of the 2D P-spline signal coefficent surface.}
}
\description{
Plotting function for 2D P-spline signal regression
coefficients (using \code{ps2DSignal} with \code{class ps2dsignal}). Although
standard error surface bands
can be comuputed they are intentially left out as they are not
interpretable, and there is generally little data to steer
such a high-dimensional parameterization.
}
\examples{
library(fields)
library(JOPS)

# Get the data
x0 <- Sugar$X
x0 <- x0 - apply(x0, 1, mean) # center Signal
y <- as.vector(Sugar$y[, 3]) # Response is Ash

# Inputs for two-dimensional signal regression
nseg <- c(7, 37)
pord <- c(3, 3)
min_ <- c(230, 275)
max_ <- c(340, 560)
M1_index <- rev(c(340, 325, 305, 290, 255, 240, 230))
M2_index <- seq(from = 275, to = 560, by = .5)
p1 <- length(M1_index)
p2 <- length(M2_index)

# Fit optimal model based on LOOCV
opt_lam <- c(8858.6679, 428.1332) # Found via svcm
Pars_opt <- rbind(
 c(min_[1], max_[1], nseg[1], 3, opt_lam[1], pord[1]),
 c(min_[2], max_[2], nseg[2], 3, opt_lam[2], pord[2]))

fit <- ps2DSignal(y, x0, p1, p2, "unfolded", M1_index, M2_index,
       Pars_opt, int = FALSE, ridge_adj = 1e-4 )

# Plotting coefficient image
plot(fit)
}
\references{
Marx, B.D. and Eilers, P.H.C. (2005).
Multidimensional penalized signal regression, \emph{Technometrics}, 47: 13-22.

Eilers, P.H.C. and Marx, B.D. (2021). \emph{Practical Smoothing, The Joys of
P-splines.} Cambridge University Press.
}
\author{
Paul Eilers and Brian Marx
}
